Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorWillian Padovani Germano <wpgermano@gmail.com>2003-10-28 03:29:37 +0300
committerWillian Padovani Germano <wpgermano@gmail.com>2003-10-28 03:29:37 +0300
commit9c6275c55babe03f377b4897dbf87341c3f80fda (patch)
treed71f3f9526207bb3cb68850089ccb66f5a901849 /source/blender/python/api2_2x/Ipo.h
parentbfef1d0d92a8a3e9e75ab337b7e9add9fae4e08b (diff)
Exppython:
- Small fix in NMesh.c - Updates to ipo related methods in Camera, World and Material - Doc updates
Diffstat (limited to 'source/blender/python/api2_2x/Ipo.h')
-rw-r--r--source/blender/python/api2_2x/Ipo.h58
1 files changed, 29 insertions, 29 deletions
diff --git a/source/blender/python/api2_2x/Ipo.h b/source/blender/python/api2_2x/Ipo.h
index c71a38dca85..1f78b613903 100644
--- a/source/blender/python/api2_2x/Ipo.h
+++ b/source/blender/python/api2_2x/Ipo.h
@@ -76,41 +76,41 @@ struct PyMethodDef M_Ipo_methods[] = {
};
/*****************************************************************************/
/* Python C_Ipo structure definition: */
/*****************************************************************************/
typedef struct {
PyObject_HEAD
Ipo *ipo;
-} C_Ipo;
+} BPy_Ipo;
/*****************************************************************************/
/* Python C_Ipo methods declarations: */
/*****************************************************************************/
-static PyObject *Ipo_getName(C_Ipo *self);
-static PyObject *Ipo_setName(C_Ipo *self, PyObject *args);
-static PyObject *Ipo_getBlocktype(C_Ipo *self);
-static PyObject *Ipo_setBlocktype(C_Ipo *self, PyObject *args);
-static PyObject *Ipo_getRctf(C_Ipo *self);
-static PyObject *Ipo_setRctf(C_Ipo *self, PyObject *args);
+static PyObject *Ipo_getName(BPy_Ipo *self);
+static PyObject *Ipo_setName(BPy_Ipo *self, PyObject *args);
+static PyObject *Ipo_getBlocktype(BPy_Ipo *self);
+static PyObject *Ipo_setBlocktype(BPy_Ipo *self, PyObject *args);
+static PyObject *Ipo_getRctf(BPy_Ipo *self);
+static PyObject *Ipo_setRctf(BPy_Ipo *self, PyObject *args);
-static PyObject *Ipo_getCurve(C_Ipo *self, PyObject *args);
-static PyObject *Ipo_getCurves(C_Ipo *self);
-static PyObject *Ipo_addCurve(C_Ipo *self, PyObject *args);
-static PyObject *Ipo_getNcurves(C_Ipo *self);
-static PyObject *Ipo_getNBezPoints(C_Ipo *self, PyObject *args);
-static PyObject *Ipo_DeleteBezPoints(C_Ipo *self, PyObject *args);
-static PyObject *Ipo_getCurveBP(C_Ipo *self, PyObject *args);
-static PyObject *Ipo_getCurvecurval(C_Ipo *self, PyObject *args);
-static PyObject *Ipo_EvaluateCurveOn(C_Ipo *self, PyObject *args);
+static PyObject *Ipo_getCurve(BPy_Ipo *self, PyObject *args);
+static PyObject *Ipo_getCurves(BPy_Ipo *self);
+static PyObject *Ipo_addCurve(BPy_Ipo *self, PyObject *args);
+static PyObject *Ipo_getNcurves(BPy_Ipo *self);
+static PyObject *Ipo_getNBezPoints(BPy_Ipo *self, PyObject *args);
+static PyObject *Ipo_DeleteBezPoints(BPy_Ipo *self, PyObject *args);
+static PyObject *Ipo_getCurveBP(BPy_Ipo *self, PyObject *args);
+static PyObject *Ipo_getCurvecurval(BPy_Ipo *self, PyObject *args);
+static PyObject *Ipo_EvaluateCurveOn(BPy_Ipo *self, PyObject *args);
-static PyObject *Ipo_setCurveBeztriple(C_Ipo *self, PyObject *args);
-static PyObject *Ipo_getCurveBeztriple(C_Ipo *self, PyObject *args);
+static PyObject *Ipo_setCurveBeztriple(BPy_Ipo *self, PyObject *args);
+static PyObject *Ipo_getCurveBeztriple(BPy_Ipo *self, PyObject *args);
/*****************************************************************************/
/* Python C_Ipo methods table: */
/*****************************************************************************/
-static PyMethodDef C_Ipo_methods[] = {
+static PyMethodDef BPy_Ipo_methods[] = {
/* name, method, flags, doc */
{"getName", (PyCFunction)Ipo_getName, METH_NOARGS,
"() - Return Ipo Data name"},
@@ -152,11 +152,11 @@ static PyMethodDef C_Ipo_methods[] = {
/*****************************************************************************/
/* Python Ipo_Type callback function prototypes: */
/*****************************************************************************/
-static void IpoDeAlloc (C_Ipo *self);
-//static int IpoPrint (C_Ipo *self, FILE *fp, int flags);
-static int IpoSetAttr (C_Ipo *self, char *name, PyObject *v);
-static PyObject *IpoGetAttr (C_Ipo *self, char *name);
-static PyObject *IpoRepr (C_Ipo *self);
+static void IpoDeAlloc (BPy_Ipo *self);
+//static int IpoPrint (BPy_Ipo *self, FILE *fp, int flags);
+static int IpoSetAttr (BPy_Ipo *self, char *name, PyObject *v);
+static PyObject *IpoGetAttr (BPy_Ipo *self, char *name);
+static PyObject *IpoRepr (BPy_Ipo *self);
/*****************************************************************************/
/* Python Ipo_Type structure definition: */
@@ -166,7 +166,7 @@ PyTypeObject Ipo_Type =
PyObject_HEAD_INIT(NULL)
0, /* ob_size */
"Ipo", /* tp_name */
- sizeof (C_Ipo), /* tp_basicsize */
+ sizeof (BPy_Ipo), /* tp_basicsize */
0, /* tp_itemsize */
/* methods */
(destructor)IpoDeAlloc, /* tp_dealloc */
@@ -182,7 +182,7 @@ PyTypeObject Ipo_Type =
0,0,0,0,0,0,
0, /* tp_doc */
0,0,0,0,0,0,
- C_Ipo_methods, /* tp_methods */
+ BPy_Ipo_methods, /* tp_methods */
0, /* tp_members */
};
@@ -76,41 +76,41 @@ struct PyMethodDef M_Ipo_methods[] = {
};
/*****************************************************************************/
-/* Python C_Ipo structure definition: */
+/* Python BPy_Ipo structure definition: */
/*****************************************************************************/
typedef struct {
@@ -76,41 +76,41 @@ struct PyMethodDef M_Ipo_methods[] = {
/*****************************************************************************/
-/* Python C_Ipo methods declarations: */
+/* Python BPy_Ipo methods declarations: */
/*****************************************************************************/
@@ -76,41 +76,41 @@ struct PyMethodDef M_Ipo_methods[] = {
/*****************************************************************************/
-/* Python C_Ipo methods table: */
+/* Python BPy_Ipo methods table: */
/*****************************************************************************/